@@ -87,13 +87,13 @@
 #' # Minimal Disparity with EM converged: 137.8368 at tol= 2
 #' 
 #' # Effect of Phenylbiguanide on Blood Pressure
-#' data(PBG, package = "nlme")
+#' \donttest{data(PBG, package = "nlme")
 #' test2 <- tolfind.boxcox(deltaBP ~ dose , groups = PBG$Rabbit, find.in.range = c(0, 2),
 #'     data = PBG, K = 2, lambda = -1, s = 15,  start = "quantile", plot.opt = 0)
 #' test2$Mintol
 #' # [1] 1.6
 #' test2$MinDisparity
-#' # [1] 449.5876
+#' # [1] 449.5876}
 #' 
 #' 
 #' 
@@ -150,7 +150,7 @@ tolfind.boxcox<- function (formula, groups=1, data, K=3,  lambda=1, EMdev.change
     step.min.conv/s
   fit <- np.boxcoxmix(formula=formula, groups= groups, data=data, K=K, lambda=lambda,steps= steps, 
                           tol = tol.min, start=start, EMdev.change = EMdev.change, 
-                          plot.opt = plot.opt, verbose = verbose)
+                          plot.opt = 0, verbose = verbose)
   aic<- fit$aic
   bic<- fit$bic
   npcolors <- 2 + all.converged
